[Current]
^^^^^^^^^

0.9.2
^^^^^

-  `0120e81 <../../commit/0120e81>`__ - **(dvenkatsagar)** version
   update: 0.9.2
-  `97d09de <../../commit/97d09de>`__ - **(dvenkatsagar)** Added an
   Example Application. vpat++
-  `552874a <../../commit/552874a>`__ - **(dvenkatsagar)** Uploaded
   files to pypi

0.9.1-r
^^^^^^^

-  `76c1947 <../../commit/76c1947>`__ - **(dvenkatsagar)** update
   changelog. releasing 0.9.1
-  `b7bd707 <../../commit/b7bd707>`__ - **(dvenkatsagar)** Removed Apps
   and added them to a seperate repository. Will be coming soon.
-  `cf7e99c <../../commit/cf7e99c>`__ - **(dvenkatsagar)** updated
   setup.py version
-  `591ed55 <../../commit/591ed55>`__ - **(dvenkatsagar)** Fixed small
   bugs
-  `f006c80 <../../commit/f006c80>`__ - **(dvenkatsagar)** updated
   documentation

0.9.1
^^^^^

-  `0357e5e <../../commit/0357e5e>`__ - **(dvenkatsagar)** version
   update: 0.9.1
-  `63a9ee5 <../../commit/63a9ee5>`__ - **(dvenkatsagar)** Added general
   multi-button support. Added example applications. Update program
   documentation. #vpat++
-  `c17f6f2 <../../commit/c17f6f2>`__ - **(dvenkatsagar)** FIxed some
   issues with the Progress bars
-  `2633601 <../../commit/2633601>`__ - **(dvenkatsagar)** Fixed Version
   Numbers
-  `8153d0b <../../commit/8153d0b>`__ - **(dvenkatsagar)** version
   update: 0.9.3
-  `b90faf3 <../../commit/b90faf3>`__ - **(dvenkatsagar)** Fixed
   CHANGELOG output. #vpat++
-  `29e95a5 <../../commit/29e95a5>`__ - **(dvenkatsagar)** Fixed the
   changelog to changelog.md

0.9.0
^^^^^

-  `9240e3e <../../commit/9240e3e>`__ - **(dvenkatsagar)** Fixed
   Changelog
-  `a07111b <../../commit/a07111b>`__ - **(dvenkatsagar)** Updated
   setup.py
-  `0e5cdd2 <../../commit/0e5cdd2>`__ - **(dvenkatsagar)** Updated
   setup.py
-  `6d4037b <../../commit/6d4037b>`__ - **(dvenkatsagar)** made changes
   to README.rst
-  `ec525c4 <../../commit/ec525c4>`__ - **(dvenkatsagar)** Made some
   final Fixes
-  `642ef0a <../../commit/642ef0a>`__ - **(dvenkatsagar)** Modified
   changelog
-  `e3aa610 <../../commit/e3aa610>`__ - **(dvenkatsagar)** made
   release-0.9.0 for deployment
-  `8699517 <../../commit/8699517>`__ - **(dvenkatsagar)** version
   update: 0.9.0 Reintroduced subprocess for progress bars. Added
   python2 support. Added Notebook functionality. Modified docs. Added
   Read Me Files. Added Setup.py files Modified Documentation. Changed
   License files. version update: 0.8.0 Switched to pexpect. Remove
   Subprocess entirely. Fixed some issues regarding the call back
   functions. version update: 0.7.7 coverted most of code for pexpect.
   Still some more to do. version update: 0.7.6 modified the list listen
   functionality. Initial commit

